using System;
using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using SimpleJSON;
using System.Threading;
using MVR;
using MeshVR;
using System.Linq;


namespace Stopper {
	public class LightOptions : MVRScript {

        AdjustLightV2 adjustLight;
        Light light;
		public override void Init() {
            adjustLight = containingAtom.GetStorableByID("Light") as AdjustLightV2;
            if(adjustLight == null){
                SuperController.LogError("Could not find AdjustLightV2. Is this a light Atom?");
                return;
            }

            light = adjustLight.GetComponent<Light>();
            if(light == null){
                SuperController.LogError("Could not find Light. Weird. Please complain on hub.");
                return;
            }

            CreateTextField(new JSONStorableString("shadowResolution", "Note: will be rounded to the nearest power of 2"), false).height = 10;
            AddSlider("Custom Shadow Resolution", 0f,0f, 1 << 15, (float val) => {
                light.shadowCustomResolution = (int)val;
            });

            AddSlider("Shadow Bias", light.shadowBias , 0f, 5f, (float val) => {
                light.shadowBias = val;
            });
		}

        public JSONStorableFloat AddSlider(string name, float defaultVal, float min, float max, JSONStorableFloat.SetFloatCallback onChange = null, bool rangeAdjust = true, bool rightSide = false){
            JSONStorableFloat storableFloat = new JSONStorableFloat(name, defaultVal, min, max, true, true);
            storableFloat.storeType = JSONStorableParam.StoreType.Full;
            UIDynamicSlider uiSlider = this.CreateSlider(storableFloat, rightSide);
            uiSlider.rangeAdjustEnabled = rangeAdjust;
            RegisterFloat(storableFloat);
            
            if(onChange != null){
                storableFloat.setCallbackFunction = onChange;
            }
            
            return storableFloat;
	    }
		
		private void Start(){
			
		}
		
		private void Update(){
		}
	
			
		private void OnDisable()
		{
		}
		
		private void OnDestroy(){
		}
    }
}
